Class: ActionController::Base

Inherits:
Object
  • Object
show all
Defined in:
lib/static_site_builder/builder.rb

Class Method Summary collapse

Class Method Details

.helpers ⇒ Object

meta-tags gem calls ActionController::Base.helpers In Rails, this returns an instance that includes ActionView::Helpers We create a simple object that extends ActionView::Helpers modules



20
21
22
23
24
25
26
# File 'lib/static_site_builder/builder.rb', line 20

def self.helpers
  @helpers ||= Object.new.tap do |helper_obj|
    helper_obj.extend(ActionView::Helpers::TagHelper)
    helper_obj.extend(ActionView::Helpers::OutputSafetyHelper)
    helper_obj.extend(ActionView::Helpers::TextHelper)
  end
end